import { TestRail, Run, AddResultForCase } from "testrail-js-api";
interface Config<T = number> {
    enabled: boolean;
    host: string;
    user: string;
    apiKey: string;
    projectId: T;
    suiteId: T;
    runId: T;
    runName: string;
    runDescription?: string;
    reference?: string;
    branchEnv: string;
    buildNoEnv: string;
    dateFormat: string;
    caseMeta: string;
    runCloseAfterDays?: number;
    uploadScreenshots: boolean;
    updateRunTestCases: boolean;
}
interface Meta {
    [key: string]: string;
}
interface TaskResult {
    passedCount: number;
    failedCount: number;
    skippedCount: number;
}
interface Screenshot {
    screenshotPath: string;
    thumbnailPath: string;
    userAgent: string;
    quarantineAttempt: number;
    takenOnFail: boolean;
}
interface TestRunInfo {
    errs: Record<string, unknown>[];
    warnings: string[];
    durationMs: number;
    unstable: boolean;
    screenshotPath: string;
    screenshots: Screenshot[];
    quarantine: {
        [key: string]: {
            passed: boolean;
        };
    };
    skipped: boolean;
}
declare class TestcafeTestrailReporter {
    noColors: boolean;
    formatError: unknown;
    private config;
    private branch;
    private buildNo;
    userAgents: string[];
    results: AddResultForCase[];
    screenshots: {
        [key: string]: Screenshot[];
    };
    constructor();
    reportTaskStart: (_startTime: number, userAgents: string[]) => Promise<void>;
    reportFixtureStart: () => Promise<void>;
    reportTestDone: (name: string, testRunInfo: TestRunInfo, meta: Meta, formatError: (x: Record<string, unknown>) => string) => Promise<void>;
    reportTaskDone: (_endTime: number, _passed: number, _warnings: string[], _result: TaskResult) => Promise<void>;
    closeOldRuns: (testrailAPI: TestRail, config: Config) => Promise<void>;
    publishTestResults: (testrailAPI: TestRail, run: Run, resultsToPush: AddResultForCase[]) => Promise<void>;
}
declare const _default: () => {
    reportTaskStart: (_startTime: number, userAgents: string[]) => Promise<void>;
    reportFixtureStart: () => Promise<void>;
    reportTestDone(name: string, testRunInfo: TestRunInfo, meta: Meta): Promise<void>;
    reportTaskDone: (_endTime: number, _passed: number, _warnings: string[], _result: TaskResult) => Promise<void>;
    reporter: TestcafeTestrailReporter;
};
export = _default;
